# acwriting

   [![pip](https://raw.githubusercontent.com/yiyualt/acwriting/536d8289fee3603d0fb261d780302a7f35cd1070/data/pip.svg)](https://pypi.org/project/pip/)
   [![LicenseMIT](https://raw.githubusercontent.com/yiyualt/acwriting/536d8289fee3603d0fb261d780302a7f35cd1070/data/LicenseMIT.svg)](./LICENSE.txt)
   [![pyversion](https://raw.githubusercontent.com/yiyualt/acwriting/536d8289fee3603d0fb261d780302a7f35cd1070/data/pyversion.svg)](https://github.com/Yoki0/acwriting)
   
   
   
## Introduction
Have you ever felt frustrated with your English writing skills?
If yes, you are in the right place! Acwriting is actually what you want!

What is acwriting?

Short answer is, it is a Python package for the English writings, designed especially for academic writings.
It can do :
*
*
*
*

So, let's get started!

## Simple example


## Installation

## Documentation

## License

